@@ -209,7 +209,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL,
     __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_BRC_DLL_PATH,
     __MEDIA_USER_FEATURE_VALUE_VP9_ENCODE_ENABLE_BRC_DLL_CUSTOMPATH,
-    __MEDIA_USER_FEATURE_VALUE_MEMNINJA_COUNTER_ID,
     __MEDIA_USER_FEATURE_VALUE_ENCODE_ENABLE_CMD_INIT_HUC_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_HEVC_ENCODE_SECURE_INPUT_ID,
@@ -277,7 +276,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_NUMBER_OF_CODEC_DEVICES_ON_VDBOX2_ID,
     __MEDIA_USER_FEATURE_VALUE_VDI_MODE_ID,
     __MEDIA_USER_FEATURE_VALUE_MEDIA_WALKER_MODE_ID,
-    __MEDIA_USER_FEATURE_VALUE_CSC_COEFF_PATCH_MODE_DISABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP8_HW_SCOREBOARD_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP8_ENCODE_ME_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VP8_ENCODE_16xME_ENABLE_ID,
@@ -402,70 +400,21 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_ENABLE_HW_DEBUG_HOOKS_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_FRAME_NUMBER_TO_STOP_ID,
     __MEDIA_USER_FEATURE_VALUE_CODECHAL_ENABLE_SW_CRC_ID,
-    __VPHAL_VEBOX_OUTPUTPIPE_MODE_ID,
-    __VPHAL_VEBOX_FEATURE_INUSE_ID,
-    __VPHAL_RNDR_SSD_CONTROL_ID,
-    __VPHAL_RNDR_SCOREBOARD_CONTROL_ID,
-    __VPHAL_RNDR_CMFC_CONTROL_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_DBG_SURF_DUMP_OUTFILE_KEY_NAME_ID,
-    __VPHAL_DBG_SURF_DUMP_LOCATION_KEY_NAME_ID,
-    __VPHAL_DBG_SURF_DUMP_MANUAL_TRIGGER_KEY_NAME_ID,
-    __VPHAL_DBG_SURF_DUMP_START_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_SURF_DUMP_END_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_SURF_DUMPER_ENABLE_PLANE_DUMP,
-    __VPHAL_DBG_SURF_DUMP_ENABLE_AUX_DUMP_ID,
-    __VPHAL_DBG_SURF_DUMPER_RESOURCE_LOCK_ID,
-    __VPHAL_DBG_STATE_DUMP_OUTFILE_KEY_NAME_ID,
-    __VPHAL_DBG_STATE_DUMP_LOCATION_KEY_NAME_ID,
-    __VPHAL_DBG_STATE_DUMP_START_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_STATE_DUMP_END_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_PARAM_DUMP_OUTFILE_KEY_NAME_ID,
-    __VPHAL_DBG_PARAM_DUMP_START_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_PARAM_DUMP_END_FRAME_KEY_NAME_ID,
-    __VPHAL_DBG_DUMP_OUTPUT_DIRECTORY_ID,
-    __VPHAL_DBG_PARA_DUMP_ENABLE_SKUWA_DUMP_ID,
 #endif
-    __VPHAL_SET_SINGLE_SLICE_VEBOX_ID,
-    __VPHAL_BYPASS_COMPOSITION_ID,
-    __VPHAL_VEBOX_DISABLE_SFC_ID,
     __VPHAL_ENABLE_MMC_ID,
     __VPHAL_ENABLE_MMC_IN_USE_ID,
     __VPHAL_PRIMARY_SURFACE_COMPRESS_MODE_ID,
     __VPHAL_PRIMARY_SURFACE_COMPRESSIBLE_ID,
     __VPHAL_RT_COMPRESS_MODE_ID,
     __VPHAL_RT_COMPRESSIBLE_ID,
-    __VPHAL_ENABLE_VEBOX_MMC_DECOMPRESS_ID,
-    __VPHAL_VEBOX_DISABLE_TEMPORAL_DENOISE_FILTER_ID,
-    __VPHAL_ENABLE_SUPER_RESOLUTION_ID,
-    __VPHAL_SUPER_RESOLUTION_MODE_ID,
-    __VPHAL_SUPER_RESOLUTION_SCENARIO_ID,
-    __VPHAL_FORCE_TO_ENABLE_SR_ID,
-    __VPHAL_SUPER_RESOLUTION_MODEL_ID,
-    __VPHAL_ENABLE_SEGMENTATION_ID,
-    __VPHAL_SEGMENTATION_MODE_ID,
-    __VPHAL_SEGMENTATION_OUTPUT_TYPE_ID,
-    __VPHAL_VEBOX_HDR_MODE_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
-    __VPHAL_COMP_8TAP_ADAPTIVE_ENABLE_ID,
-    __VPHAL_RNDR_FORCE_VP_DECOMPRESSED_OUTPUT_ID,
     __VPHAL_ENABLE_1K_1DLUT_ID,
-    __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED_ID,
-    __VPHAL_ENABLE_SFC_NV12_P010_LINEAR_OUTPUT_ID,
-    __VPHAL_ENABLE_SFC_RGBP_RGB24_OUTPUT_ID,
-    __VPHAL_SEGMENTATION_ENQUEUE_MODE_ID,
-#endif
-#if ((_DEBUG || _RELEASE_INTERNAL) && !EMUL)
-    __VPHAL_RNDR_VEBOX_MODE_0_ID,
-    __VPHAL_RNDR_VEBOX_MODE_0_TO_2_ID,
-    __VPHAL_RNDR_VEBOX_MODE_2_ID,
-    __VPHAL_RNDR_VEBOX_MODE_2_TO_0_ID,
 #endif
 #if (_DEBUG || _RELEASE_INTERNAL)
     __VPHAL_ENABLE_COMPUTE_CONTEXT_ID,
-    __VPHAL_DISPLAY_COLORIMETRIC_CONTROL_ID,
 #endif
-    __MOS_USER_FEATURE_KEY_VP_CAPS_FF_OVERRIDE_ID,
     __MOS_USER_FEATURE_KEY_XML_AUTOGEN_ID,
     __MOS_USER_FEATURE_KEY_XML_FILEPATH_ID,
     __MOS_USER_FEATURE_KEY_XML_DUMP_GROUPS_ID,
@@ -503,8 +452,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_CMD_PARS_FILES_DIRECORY_ID,
     __MEDIA_USER_FEATURE_VALUE_APOGEIOS_ENABLE_ID,
     __MEDIA_USER_FEATURE_VALUE_VPP_APOGEIOS_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SUPER_RESOLUTION_ENABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SUPER_RESOLUTION_MODEL_ID,
     __MEDIA_USER_FEATURE_VALUE_EXTERNAL_COPY_SYNC_ID,
     __MEDIA_USER_FEATURE_VALUE_ENABLE_UMD_OCA_ID,
     __MEDIA_USER_FEATURE_VALUE_COUNT_FOR_OCA_BUFFER_LEAKED_ID,
@@ -516,8 +463,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_START_COUNTER_ID,
     __MEDIA_USER_FEATURE_VALUE_INTER_FRAME_MEMORY_NINJA_END_COUNTER_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
-    __MEDIA_USER_FEATURE_VALUE_FORCE_TO_DISABLE_SR_ID,
-    __MEDIA_USER_FEATURE_VALUE_INIT_CP_OUTPUT_SURFACE_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_MODE_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_FREQ_ID,
     __MEDIA_USER_FEATURE_VALUE_ALLOC_MEMORY_FAIL_SIMULATE_HINT_ID,
@@ -546,7 +491,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PLATFORM_ID,
     __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_STEPPING_ID,
     __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_DEVICE_ID,
-    __MEDIA_USER_FEATURE_VALUE_RENDER_ENABLE_EUFUSION_ID,
     __MEDIA_USER_FEATURE_VALUE_DISABLE_TLB_PREFETCH_ID,
 #if (_DEBUG || _RELEASE_INTERNAL)
     __MEDIA_USER_FEATURE_VALUE_FORCE_DECODE_RESOURCE_LOCKABLE_ID,
@@ -558,9 +502,6 @@ typedef enum _MOS_USER_FEATURE_VALUE_ID
     __MEDIA_USER_FEATURE_VALUE_HUC_LOAD_STATUS_ID,
     __MEDIA_USER_FEATURE_VALUE_HUC_REPORT_CRITICAL_ERROR_ID,
 
-    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_CENTERING_DISABLE_ID,
-    __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_DTR_DISABLE_ID,
-
     __MOS_USER_FEATURE_KEY_MAX_ID,
 } MOS_USER_FEATURE_VALUE_ID;
 
@@ -816,6 +757,8 @@ typedef struct
     uint32_t Length;
 } MOS_USER_FEATURE_KEY_PATH_INFO, *PMOS_USER_FEATURE_KEY_PATH_INFO;
 
+#include "mos_util_user_feature_keys.h"
+
 #ifdef __cplusplus
 //Memory alloc fail simulatiion related defination
 #if (_DEBUG || _RELEASE_INTERNAL)
