@@ -28,8 +28,8 @@
 //!
 #include "vphal_renderer_xe_hpm.h"
 #if defined(ENABLE_KERNELS)
-#include "igvpkrn_xe_hpm.h"
-#include "igvpkrn_xe_hpm_cmfcpatch.h"
+#include "igvpkrn_xe_hpg.h"
+#include "igvpkrn_xe_hpg_cmfcpatch.h"
 #endif
 #include "vphal_render_vebox_xe_hpm.h"
 #include "vphal_render_composite_xe_xpm.h"
@@ -210,10 +210,10 @@ MOS_STATUS VphalRendererXe_Hpm::InitKdllParam()
     {
         pKernelDllRules  = g_KdllRuleTable_Xe_Hpm;
 #if defined(ENABLE_KERNELS)
-        pcKernelBin      = (const void *)IGVPKRN_XE_HPM;
-        dwKernelBinSize  = IGVPKRN_XE_HPM_SIZE;
-        pcFcPatchBin     = (const void *)IGVPKRN_XE_HPM_CMFCPATCH;
-        dwFcPatchBinSize = IGVPKRN_XE_HPM_CMFCPATCH_SIZE;
+        pcKernelBin      = (const void *)IGVPKRN_XE_HPG;
+        dwKernelBinSize  = IGVPKRN_XE_HPG_SIZE;
+        pcFcPatchBin     = (const void *)IGVPKRN_XE_HPG_CMFCPATCH;
+        dwFcPatchBinSize = IGVPKRN_XE_HPG_CMFCPATCH_SIZE;
 #else
         pcKernelBin      = nullptr;
         dwKernelBinSize  = 0;
@@ -575,7 +575,7 @@ MOS_STATUS VphalRendererXe_Hpm::RenderScaling(
         VPHAL_RENDER_CHK_STATUS(RenderPass(&renderParams));
         m_pDSSurface[0]->rcSrc          = m_pDSSurface[0]->rcDst;
         m_pDSSurface[0]->rcMaxSrc       = m_pDSSurface[0]->rcDst;
-        m_pDSSurface[0]->rcDst          = pTarget->rcDst;
+        m_pDSSurface[0]->rcDst          = pSource->rcDst;
         pDSSurface                      = m_pDSSurface[0];
     }
 
