@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2017, Intel Corporation
+* Copyright (c) 2017-2021, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -38,6 +38,7 @@
 #define CODECHAL_ENCODE_AVC_INIT_DSH_SIZE                   MHW_PAGE_SIZE * 3
 #define CODECHAL_ENCODE_AVC_MAX_SLICE_QP                    (CODEC_AVC_NUM_QP - 1) // 0 - 51 inclusive
 #define CODECHAL_ENCODE_AVC_MIN_ICQ_QUALITYFACTOR           1
+#define CODECHAL_ENCODE_AVC_VDENC_MIN_ICQ_QUALITYFACTOR     11
 #define CODECHAL_ENCODE_AVC_MAX_ICQ_QUALITYFACTOR           51
 #define CODECHAL_ENCODE_AVC_MAX_SLICES_SUPPORTED            256
 #define CODECHAL_ENCODE_AVC_DEFAULT_AVBR_ACCURACY           30
@@ -90,6 +91,9 @@ struct EncodeAvcPar
     uint16_t                    FrameRateD;
     uint16_t                    CRFQualityFactor;
     uint32_t                    NumSlices;
+    uint32_t                    SliceHeight;
+    uint32_t                    NumSuperSlices;
+    uint32_t                    SuperSliceHeight[CODECHAL_ENCODE_AVC_MAX_SLICES_SUPPORTED];
     bool                        ConstrainedIntraPred;
     uint8_t                     SliceMode;
     int16_t                     hme0XOffset;
@@ -232,6 +236,8 @@ struct EncodeAvcPar
     uint8_t                     ForceIPCMMinQP;
     uint8_t                     IntraTr4x4Percent;
     bool                        MultiPassHmeEnable;
+    uint32_t                    IntraPredictionIFrame;
+    uint32_t                    IntraPrediction;
 
     // PAK Params
     uint8_t                     RoundingIntra;
@@ -279,6 +285,7 @@ typedef struct _CODECHAL_ENCODE_AVC_GENERIC_PICTURE_LEVEL_PARAMS
     bool                        bDeblockerStreamOutEnable;
     bool                        bPostDeblockOutEnable;
     bool                        bPreDeblockOutEnable;
+    bool                        bPerMBStreamOutEnable;
 } CODECHAL_ENCODE_AVC_GENERIC_PICTURE_LEVEL_PARAMS, *PCODECHAL_ENCODE_AVC_GENERIC_PICTURE_LEVEL_PARAMS;
 
 typedef struct _CODECHAL_ENCODE_AVC_ME_CURBE
@@ -1608,6 +1615,15 @@ public:
         PMOS_COMMAND_BUFFER            cmdBuffer,
         uint32_t                       currPass);
 
+    virtual MOS_STATUS AddMfxAvcSlice(
+        PMOS_COMMAND_BUFFER        cmdBuffer,
+        PMHW_BATCH_BUFFER          batchBuffer,
+        PMHW_VDBOX_AVC_SLICE_STATE avcSliceState);
+
+    virtual MOS_STATUS AddVdencSliceStateCmd(
+        PMOS_COMMAND_BUFFER        cmdBuffer,
+        PMHW_VDBOX_AVC_SLICE_STATE params);
+
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS DumpSeqParams(
         PCODEC_AVC_ENCODE_SEQUENCE_PARAMS seqParams,
@@ -1719,6 +1735,8 @@ public:
     PCODEC_AVC_IQ_MATRIX_PARAMS              m_avcIQMatrixParams     = nullptr;  //!< Pointer to IQMaxtrix parameter
     PCODEC_AVC_ENCODE_IQ_WEIGTHSCALE_LISTS      m_avcIQWeightScaleLists = nullptr;  //!< Pointer to IQWidght ScaleLists
     CODEC_AVC_ENCODE_USER_FLAGS                 m_userFlags;                        //!< Encoder user flag settings
+    uint32_t                                    m_reconFrameSurfaceId[CODEC_AVC_NUM_UNCOMPRESSED_SURFACE];
+    CODECHAL_ENCODE_AVC_ENCODER_USAGE           m_encoderUsage = CODECHAL_ENCODE_AVC_SINGLE_PASS;
 
     CODEC_PIC_ID                                m_picIdx[CODEC_AVC_MAX_NUM_REF_FRAME];              //!< Picture index
     PCODEC_REF_LIST                             m_refList[CODEC_AVC_NUM_UNCOMPRESSED_SURFACE];   //!< Pointer to reference list
