@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2019, Intel Corporation
+* Copyright (c) 2009-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -33,6 +33,7 @@
 #include "mos_util_debug.h"
 #include "mos_util_user_interface.h"
 #include "mos_interface.h"
+#include "media_user_setting.h"
 
 PerfUtility* g_perfutility = PerfUtility::getInstance();
 
@@ -104,7 +105,17 @@ MOS_STATUS Mos_OsFillResource(
 
     uint8_t *       pByte = nullptr;
     MOS_LOCK_PARAMS LockFlags;
-
+    uint32_t        size = 0;
+#ifndef VPSOLO_EMUL
+    if (pOsResource->pGmmResInfo)
+    {
+        size = (uint32_t)pOsResource->pGmmResInfo->GetSizeSurface();
+    }
+    if (dwSize > size)
+    {
+        MOS_OS_ASSERTMESSAGE("dwSize (%x)> size (%x)", dwSize, size);
+    }
+#endif
     // Lock the surface for writing
     MOS_ZeroMemory(&LockFlags, sizeof(MOS_LOCK_PARAMS));
 
@@ -211,6 +222,7 @@ MOS_STATUS Mos_OsGetBitsPerPixel(
     case Format_A8P8:
     case Format_A8L8:
     case Format_R16U:
+    case Format_V8U8:
         *piBpp = 16;
         break;
 
@@ -268,6 +280,7 @@ MOS_STATUS Mos_OsGetBitsPerPixel(
     case Format_Buffer:
     case Format_RAW:
     case Format_R8U:
+    case Format_R8UN:
        *piBpp = 8;
         break;
 
@@ -437,7 +450,7 @@ MOS_STATUS Mos_DumpCommandBuffer(
             MOS_DIR_SEPERATOR, MOS_COMMAND_BUFFER_OUT_FILE, dwCommandBufferNumber);
 
         // Write the output buffer to file.
-        MOS_OS_CHK_STATUS(MOS_WriteFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
+        MOS_OS_CHK_STATUS(MosUtilities::MosWriteFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
     }
 
     if (pOsInterface->bDumpCommandBufferAsMessages)
@@ -462,7 +475,7 @@ MOS_STATUS Mos_DumpCommandBuffer(
         {
             if (pOsInterface->bDumpCommandBufferToFile)
             {
-                MOS_OS_CHK_STATUS(MOS_AppendFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
+                MOS_OS_CHK_STATUS(MosUtilities::MosAppendFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
             }
             if (pOsInterface->bDumpCommandBufferAsMessages)
             {
@@ -476,7 +489,7 @@ MOS_STATUS Mos_DumpCommandBuffer(
 
     if (pOsInterface->bDumpCommandBufferToFile)
     {
-        MOS_OS_CHK_STATUS(MOS_AppendFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
+        MOS_OS_CHK_STATUS(MosUtilities::MosAppendFileFromPtr((const char *)sFileName, pOutputBuffer, dwBytesWritten));
     }
 
     if (pOsInterface->bDumpCommandBufferAsMessages)
@@ -513,16 +526,19 @@ MOS_STATUS Mos_DumpCommandBufferInit(
     MOS_USER_FEATURE_VALUE_DATA         UserFeatureData;
     char                                *psFileNameAfterPrefix = nullptr;
     size_t                              nSizeFileNamePrefix = 0;
+    MediaUserSettingSharedPtr           userSettingPtr = nullptr;
 
     MOS_OS_CHK_NULL_RETURN(pOsInterface);
 
+    userSettingPtr = pOsInterface->pfnGetUserSettingInstance(pOsInterface);
     // Setup member function and variable.
     pOsInterface->pfnDumpCommandBuffer  = Mos_DumpCommandBuffer;
     // Check if command buffer dump was enabled in user feature.
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_BUFFER_ENABLE_ID,
-        &UserFeatureData);
+        &UserFeatureData,
+        pOsInterface->pOsContext);
     pOsInterface->bDumpCommandBuffer = (UserFeatureData.i32Data != 0);
     pOsInterface->bDumpCommandBufferToFile = ((UserFeatureData.i32Data & 1) != 0);
     pOsInterface->bDumpCommandBufferAsMessages = ((UserFeatureData.i32Data & 2) != 0);
@@ -530,7 +546,7 @@ MOS_STATUS Mos_DumpCommandBufferInit(
     if (pOsInterface->bDumpCommandBufferToFile)
     {
         // Create output directory.
-        eStatus = MOS_LogFileNamePrefix(pOsInterface->sDirName);
+        eStatus = MosUtilDebug::MosLogFileNamePrefix(pOsInterface->sDirName, userSettingPtr);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create log file prefix. Status = %d", eStatus);
@@ -546,7 +562,7 @@ MOS_STATUS Mos_DumpCommandBufferInit(
             "%c%s",
             MOS_DIR_SEPERATOR, MOS_COMMAND_BUFFER_OUT_DIR);
 
-        eStatus = MOS_CreateDirectory(sFileName);
+        eStatus = MosUtilities::MosCreateDirectory(sFileName);
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             MOS_OS_NORMALMESSAGE("Failed to create output directory. Status = %d", eStatus);
@@ -567,23 +583,24 @@ finish:
 
 std::shared_ptr<GpuCmdResInfoDump> GpuCmdResInfoDump::m_instance = nullptr;
 
-const GpuCmdResInfoDump *GpuCmdResInfoDump::GetInstance()
+const GpuCmdResInfoDump *GpuCmdResInfoDump::GetInstance(PMOS_CONTEXT mosCtx)
 {
     if (m_instance == nullptr)
     {
-        m_instance = std::make_shared<GpuCmdResInfoDump>();
+        m_instance = std::make_shared<GpuCmdResInfoDump>(mosCtx);
     }
     return m_instance.get();
 }
 
-GpuCmdResInfoDump::GpuCmdResInfoDump()
+GpuCmdResInfoDump::GpuCmdResInfoDump(PMOS_CONTEXT mosCtx)
 {
     MOS_USER_FEATURE_VALUE_DATA userFeatureData;
     MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_ENABLE_ID,
-        &userFeatureData);
+        &userFeatureData,
+        mosCtx);
     m_dumpEnabled = userFeatureData.bData;
 
     if (!m_dumpEnabled)
@@ -598,7 +615,8 @@ GpuCmdResInfoDump::GpuCmdResInfoDump()
     MOS_UserFeature_ReadValue_ID(
         nullptr,
         __MEDIA_USER_FEATURE_VALUE_DUMP_COMMAND_INFO_PATH_ID,
-        &userFeatureData);
+        &userFeatureData,
+        mosCtx);
     if (userFeatureData.StringData.uSize > MOS_MAX_PATH_LENGTH)
     {
         userFeatureData.StringData.uSize = 0;
@@ -614,7 +632,7 @@ GpuCmdResInfoDump::GpuCmdResInfoDump()
     {
         tmpPath += '/';
     }
-    m_path = tmpPath + "gpuCmdResInfo_" + std::to_string(MOS_GetPid()) + ".txt";
+    m_path = tmpPath + "gpuCmdResInfo_" + std::to_string(MosUtilities::MosGetPid()) + ".txt";
 }
 
 void GpuCmdResInfoDump::Dump(PMOS_INTERFACE pOsInterface) const
@@ -737,7 +755,8 @@ MOS_STATUS Mos_InitInterface(
     MOS_UserFeature_WriteValues_ID(
         nullptr,
         &UserFeatureWriteData,
-        1);
+        1,
+        pOsInterface->pOsContext);
 
     // Apo wrapper
     if (pOsInterface->apoMosEnabled && !pOsInterface->streamStateIniter)
@@ -763,6 +782,7 @@ MOS_STATUS Mos_InitInterface(
 
         pOsInterface->osStreamState->ctxBasedScheduling       = pOsInterface->ctxBasedScheduling;
         pOsInterface->osStreamState->multiNodeScaling         = pOsInterface->multiNodeScaling;
+        pOsInterface->osStreamState->bGucSubmission           = pOsInterface->bGucSubmission;
         pOsInterface->osStreamState->perStreamParameters      = pOsInterface->pOsContext;
     }
 
@@ -952,7 +972,7 @@ MEMORY_OBJECT_CONTROL_STATE Mos_CachePolicyGetMemoryObject(
 #ifndef SKIP_VE_DEFINE
 MOS_STATUS Mos_CheckVirtualEngineSupported(
     PMOS_INTERFACE      osInterface,
-    bool                isDecode,
+    bool                isNotEncode,
     bool                veDefaultEnable)
 {
     MOS_STATUS                  eStatus = MOS_STATUS_SUCCESS;
@@ -964,7 +984,7 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
 
     osInterface->pfnGetPlatform(osInterface, &platform);
 
-    if (isDecode)
+    if (isNotEncode)
     {
         //UMD Decode Virtual Engine Override
         // 0: disable. can set to 1 only when KMD VE is enabled.
@@ -973,7 +993,8 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         eStatus = MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VIRTUAL_ENGINE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            osInterface->pOsContext);
         osInterface->bSupportVirtualEngine = userFeatureData.u32Data ? true : false;
 
         // force bSupportVirtualEngine to false when virtual engine not enabled by default
@@ -1005,7 +1026,7 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         MOS_USER_FEATURE_VALUE_WRITE_DATA  userFeatureWriteData = __NULL_USER_FEATURE_VALUE_WRITE_DATA__;
         userFeatureWriteData.Value.i32Data = osInterface->ctxBasedScheduling ? true : false;
         userFeatureWriteData.ValueID = __MEDIA_USER_FEATURE_VALUE_ENABLE_DECODE_VE_CTXSCHEDULING_ID;
-        MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1);
+        MOS_UserFeature_WriteValues_ID(nullptr, &userFeatureWriteData, 1, osInterface->pOsContext);
 #endif
     }
     else
@@ -1015,7 +1036,8 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
         eStatus = MOS_UserFeature_ReadValue_ID(
             nullptr,
             __MEDIA_USER_FEATURE_VALUE_ENABLE_ENCODE_VIRTUAL_ENGINE_ID,
-            &userFeatureData);
+            &userFeatureData,
+            osInterface->pOsContext);
         osInterface->bSupportVirtualEngine = userFeatureData.u32Data ? true : false;
 
         // force bSupportVirtualEngine to false when virtual engine not enabled by default
@@ -1051,5 +1073,5 @@ MOS_STATUS Mos_CheckVirtualEngineSupported(
 }
 #endif // !SKIP_VE_DEFINE
 
-
+void *MosStreamState::pvSoloContext = nullptr; 
 
