@@ -196,6 +196,16 @@ public:
         PVPHAL_SURFACE              pRenderTarget,
         PCVPHAL_RENDER_PARAMS       pcRenderParams);
 
+    //!
+    //! \brief    check whether SFC Write have offset which may hit compresed write limitation
+    //! \details  check whether SFC Write have offset which may hit compresed write limitation
+    //! \param    [in] pRenderTarget
+    //!           Pointer to RenderTarget
+    //! \return   the output pipe mode
+    //!
+    virtual bool IsSFCUncompressedWriteNeeded(
+        PVPHAL_SURFACE              pRenderTarget);
+
     //!
     //! \brief    Check if SFC is feasible to generate output
     //! \param    [in] pcRenderParams
@@ -601,6 +611,7 @@ protected:
 
     VPHAL_SFC_RENDER_DATA           m_renderData = {};                          //!< Transient Render data populated for every BLT call
 
+    MediaUserSettingSharedPtr m_userSettingPtr = nullptr;                       //!< usersettingInstance
 };
 #else
 // A dummy class that does nothing when SFC is not supported
