@@ -389,7 +389,6 @@ static bool InitTglMediaWaExt(struct GfxDeviceInfo *devInfo,
     /*software wa to fix some corner hang cases for Scalability*/
     MEDIA_WR_WA(waTable, Wa_2209620131, 1);
 
-    MEDIA_WR_WA(waTable, WaDisableVeboxFor8K, 1);
     
     if (drvInfo->devId == 0x9A49 ||
         drvInfo->devId == 0x9AC9 ||
@@ -731,6 +730,10 @@ static bool InitPvcMediaWa(struct GfxDeviceInfo *devInfo,
 
     // I as P WA
     MEDIA_WR_WA(waTable, Wa_22011549751, 1);
+
+    // Remove the WA of DummyReference
+    MEDIA_WR_WA(waTable, WaDummyReference, 0);
+
     return true;
 }
 
@@ -773,9 +776,15 @@ static bool InitDg2MediaSku(struct GfxDeviceInfo *devInfo,
     // Enable AV1 Large Scale Tile decoding
     MEDIA_WR_SKU(skuTable, FtrAV1VLDLSTDecoding, 1);
 
+    // Enable HDR
+    MEDIA_WR_SKU(skuTable, FtrHDR, 1);
+
     // Enable down scaling first if 3DLUT enabled
     MEDIA_WR_SKU(skuTable, FtrScalingFirst, 1);
 
+    // Disable HEVC 422 Virtual Tile Scalability
+    MEDIA_WR_SKU(skuTable, FtrDecodeHEVC422VTScalaDisable, 1);
+
     // Tile64
     if (drvInfo->devRev >=0x04 &&
         (drvInfo->devId == 0x4F80 ||
@@ -805,6 +814,8 @@ static bool InitDg2MediaSku(struct GfxDeviceInfo *devInfo,
         MEDIA_WR_SKU(skuTable, FtrMediaTile64, 1);
     }
 
+    MEDIA_WR_SKU(skuTable, FtrHDR, 1);
+
     return true;
 }
 
@@ -890,6 +901,9 @@ static bool InitDg2MediaWa(struct GfxDeviceInfo *devInfo,
 
     MEDIA_WR_WA(waTable, Wa_15010089951, 1);
 
+    // Remove the WA of DummyReference
+    MEDIA_WR_WA(waTable, WaDummyReference, 0);
+
     return true;
 }
 
