@@ -138,6 +138,27 @@ VAStatus DdiDecodeHEVC::ParseSliceParams(
         }
         codecSlcParams++;
     }
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_SLICEPARAM))
+    {
+        if (m_ddiDecodeCtx->bShortFormatInUse)
+        {
+            DECODE_EVENTDATA_SLICEPARAM_HEVC *pEventData = (DECODE_EVENTDATA_SLICEPARAM_HEVC *)MOS_AllocMemory(numSlices * sizeof(DECODE_EVENTDATA_SLICEPARAM_HEVC));
+            DecodeEventDataHEVCSliceParamInit(pEventData, (PCODEC_HEVC_SLICE_PARAMS)(m_ddiDecodeCtx->DecodeParams.m_sliceParams), numSlices);
+            MOS_TraceEvent(EVENT_DECODE_BUFFER_SLICEPARAM_HEVC, EVENT_TYPE_INFO, &numSlices, sizeof(uint32_t), pEventData, numSlices * sizeof(DECODE_EVENTDATA_SLICEPARAM_HEVC));
+            MOS_FreeMemory(pEventData);
+        }
+        else
+        {
+            DECODE_EVENTDATA_LONGSLICEPARAM_HEVC *pEventData = (DECODE_EVENTDATA_LONGSLICEPARAM_HEVC *)MOS_AllocMemory(numSlices * sizeof(DECODE_EVENTDATA_LONGSLICEPARAM_HEVC));
+            DecodeEventDataHEVCLongSliceParamInit(pEventData, (PCODEC_HEVC_SLICE_PARAMS)(m_ddiDecodeCtx->DecodeParams.m_sliceParams), numSlices);
+            MOS_TraceEvent(EVENT_DECODE_BUFFER_LONGSLICEPARAM_HEVC, EVENT_TYPE_INFO, &numSlices, sizeof(uint32_t), pEventData, numSlices * sizeof(DECODE_EVENTDATA_LONGSLICEPARAM_HEVC));
+            MOS_FreeMemory(pEventData);
+        }
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -313,6 +334,15 @@ VAStatus DdiDecodeHEVC::ParsePicParams(
     codecPicParams->RefBottomFieldFlag         = 0;
     codecPicParams->StatusReportFeedbackNumber = 0;
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
+    {
+        DECODE_EVENTDATA_PICPARAM_HEVC eventData;
+        DecodeEventDataHEVCPicParamInit(&eventData, codecPicParams);
+        MOS_TraceEvent(EVENT_DECODE_BUFFER_PICPARAM_HEVC, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -402,6 +432,33 @@ VAStatus DdiDecodeHEVC::RenderPicture(
 
             DdiMedia_MediaBufferToMosResource(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], &m_ddiDecodeCtx->BufMgr.resBitstreamBuffer);
             m_ddiDecodeCtx->DecodeParams.m_dataSize += dataSize;
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            uint8_t * pDataBuf = (uint8_t *)DdiMediaUtil_LockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], MOS_LOCKFLAG_READONLY);
+            DDI_CHK_NULL(pDataBuf, "nullptr bitstream", VA_STATUS_ERROR_INVALID_BUFFER);
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM_32BYTE))
+            {
+                DECODE_EVENTDATA_BITSTREAM eventData;
+                for (int i = 0; i < 32; i++)
+                {
+                    eventData.Data[i] = pDataBuf[i];
+                }
+                MOS_TraceEvent(EVENT_DECODE_BUFFER_Bitstream, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+            }
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM))
+            {
+                MOS_TraceDataDump(
+                "Decode_Bitstream",
+                0,
+                pDataBuf,
+                m_ddiDecodeCtx->DecodeParams.m_dataSize);
+            }
+                
+            DdiMediaUtil_UnlockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index]);
+#endif
+
             break;
         }
         case VASliceParameterBufferType:
@@ -423,6 +480,18 @@ VAStatus DdiDecodeHEVC::RenderPicture(
         {
             VAIQMatrixBufferHEVC *imxBuf = (VAIQMatrixBufferHEVC *)data;
             DDI_CHK_RET(ParseIQMatrix(mediaCtx, imxBuf),"ParseIQMatrix failed!");
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_QMATRIX))
+            {
+                MOS_TraceDataDump(
+                    "Decode_QMatrix",
+                    0,
+                    imxBuf,
+                    sizeof(VAIQMatrixBufferHEVC));
+            }
+#endif
+
             break;
         }
         case VAPictureParameterBufferType:
@@ -442,6 +511,18 @@ VAStatus DdiDecodeHEVC::RenderPicture(
             }
 
             MOS_SecureMemcpy(m_ddiDecodeCtx->DecodeParams.m_subsetParams, dataSize, data, dataSize);
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_SUBSET))
+            {
+                MOS_TraceDataDump(
+                    "Decode_Subset",
+                    0,
+                    m_ddiDecodeCtx->DecodeParams.m_subsetParams,
+                    dataSize);
+            }
+#endif
+
             break;
         }
         case VAProcPipelineParameterBufferType:
