@@ -71,6 +71,15 @@ VAStatus DdiDecodeVP9::ParseSliceParams(
         segParams->SegData[i].ChromaDCQuantScale = slcParam->seg_param[i].chroma_dc_quant_scale;
     }
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
+    {
+        DECODE_EVENTDATA_SEGPARAM_VP9 eventDataSegParam;
+        DecodeEventDataVP9SegParamInit(&eventDataSegParam, picParam, segParams->SegData);
+        MOS_TraceEvent(EVENT_DECODE_BUFFER_SEGPARAM_VP9, EVENT_TYPE_INFO, &eventDataSegParam, sizeof(eventDataSegParam), NULL, 0);
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -178,6 +187,15 @@ VAStatus DdiDecodeVP9::ParsePicParams(
     MOS_SecureMemcpy(picVp9Params->SegTreeProbs, 7, picParam->mb_segment_tree_probs, 7);
     MOS_SecureMemcpy(picVp9Params->SegPredProbs, 3, picParam->segment_pred_probs, 3);
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
+    {
+        DECODE_EVENTDATA_PICPARAM_VP9 eventDataPicParam;
+        DecodeEventDataVP9PicParamInit(&eventDataPicParam, picVp9Params);
+        MOS_TraceEvent(EVENT_DECODE_BUFFER_PICPARAM_VP9, EVENT_TYPE_INFO, &eventDataPicParam, sizeof(eventDataPicParam), NULL, 0);
+    }
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -253,6 +271,33 @@ VAStatus DdiDecodeVP9::RenderPicture(
             DdiMedia_MediaBufferToMosResource(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], &m_ddiDecodeCtx->BufMgr.resBitstreamBuffer);
             m_ddiDecodeCtx->DecodeParams.m_dataSize += dataSize;
             slcFlag = true;
+
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+            uint8_t *pDataBuf = (uint8_t *)DdiMediaUtil_LockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], MOS_LOCKFLAG_READONLY);
+            DDI_CHK_NULL(pDataBuf, "nullptr bitstream", VA_STATUS_ERROR_INVALID_BUFFER);
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM_32BYTE))
+            {
+                DECODE_EVENTDATA_BITSTREAM eventData;
+                for (int i = 0; i < 32; i++)
+                {
+                    eventData.Data[i] = pDataBuf[i];
+                }
+                MOS_TraceEvent(EVENT_DECODE_BUFFER_Bitstream, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+            }
+
+            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM))
+            {
+                MOS_TraceDataDump(
+                "Decode_Bitstream",
+                0,
+                pDataBuf,
+                m_ddiDecodeCtx->DecodeParams.m_dataSize);
+            }
+                
+            DdiMediaUtil_UnlockBuffer(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index]);
+#endif
+
             break;
         }
         case VASliceParameterBufferType:
