@@ -277,63 +277,67 @@ MOS_STATUS GpuContextSpecific::Init(OsContext *osContext,
 
             if (nengine >= 2)
             {
-                if(!osInterface->bGucSubmission)
+                int i;
+                //master queue
+                m_i915Context[1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
+                                                                    osInterface->pOsContext->intel_context,
+                                                                    I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
+                if (m_i915Context[1] == nullptr)
                 {
-                    //master queue
-                    m_i915Context[1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
-                                                                     osInterface->pOsContext->intel_context,
-                                                                     I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                    if (m_i915Context[1] == nullptr)
+                    MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
+                    MOS_SafeFreeMemory(engine_map);
+                    return MOS_STATUS_UNKNOWN;
+                }
+                m_i915Context[1]->pOsContext = osInterface->pOsContext;
+
+                if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
+                {
+                    MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
+                    MOS_SafeFreeMemory(engine_map);
+                    return MOS_STATUS_UNKNOWN;
+                }
+
+                //slave queue
+                for (i=1; i<nengine; i++)
+                {
+                    m_i915Context[i+1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
+                                                                        osInterface->pOsContext->intel_context,
+                                                                        I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
+                    if (m_i915Context[i+1] == nullptr)
                     {
-                        MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
+                        MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
                         MOS_SafeFreeMemory(engine_map);
                         return MOS_STATUS_UNKNOWN;
                     }
-                    m_i915Context[1]->pOsContext = osInterface->pOsContext;
+                    m_i915Context[i+1]->pOsContext = osInterface->pOsContext;
 
-                    if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
+                    if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
                     {
-                        MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
-                        MOS_SafeFreeMemory(engine_map);
-                        return MOS_STATUS_UNKNOWN;
-                    }
-
-                    //slave queue
-                    for (int i=1; i<nengine; i++)
-                    {
-                        m_i915Context[i+1] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
-                                                                         osInterface->pOsContext->intel_context,
-                                                                         I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE);
-                        if (m_i915Context[i+1] == nullptr)
+                        int err = errno;
+                        if (err == ENODEV)
                         {
-                            MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
+                            mos_gem_context_destroy(m_i915Context[1]);
+                            mos_gem_context_destroy(m_i915Context[i+1]);
+                            m_i915Context[i+1] = nullptr;
+                            break;
+                        }
+                        else
+                        {
+                            MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
                             MOS_SafeFreeMemory(engine_map);
                             return MOS_STATUS_UNKNOWN;
                         }
-                        m_i915Context[i+1]->pOsContext = osInterface->pOsContext;
-
-                        if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
-                        {
-                            int err = errno;
-                            if (err == ENODEV)
-                            {
-                                mos_gem_context_destroy(m_i915Context[i+1]);
-                                m_i915Context[i+1] = nullptr;
-                                break;
-                            }
-                            else
-                            {
-                                MOS_OS_ASSERTMESSAGE("Failed to set slave context bond extension. errno=%d\n",err);
-                                MOS_SafeFreeMemory(engine_map);
-                                return MOS_STATUS_UNKNOWN;
-                            }
-                        }
                     }
                 }
+                if (i == nengine)
+                {
+                    osInterface->bGucSubmission = false;
+                }
                 else
                 {
+                    osInterface->bGucSubmission = true;
                     //create context with different width
-                    for(int i = 1; i < nengine; i++)
+                    for(i = 1; i < nengine; i++)
                     {
                         unsigned int ctxWidth = i + 1;
                         m_i915Context[i] = mos_gem_context_create_shared(osInterface->pOsContext->bufmgr,
@@ -965,6 +969,7 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
             }
         }
 
+        MOS_OS_CHK_NULL_RETURN(tempCmdBo->virt);
         if (osContext->bUse64BitRelocs)
         {
             *((uint64_t *)((uint8_t *)tempCmdBo->virt + currentPatch->PatchOffset)) =
