@@ -186,6 +186,7 @@ static struct GfxDeviceInfo tgllpGt1Info = {
     .productFamily = IGFX_TIGERLAKE_LP,
     .displayFamily = IGFX_GEN12_CORE,
     .renderFamily  = IGFX_GEN12_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT1,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 4,
@@ -206,6 +207,7 @@ static struct GfxDeviceInfo tgllpGt2Info = {
     .productFamily = IGFX_TIGERLAKE_LP,
     .displayFamily = IGFX_GEN12_CORE,
     .renderFamily  = IGFX_GEN12_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT2,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 8,
@@ -227,6 +229,7 @@ static struct GfxDeviceInfo dg1Gt2Info = {
     .productFamily = IGFX_DG1,
     .displayFamily = IGFX_GEN12_CORE,
     .renderFamily  = IGFX_GEN12_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT2,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 8,
@@ -261,6 +264,7 @@ static struct GfxDeviceInfo rklGt1Info = {
     .productFamily    = IGFX_ROCKETLAKE,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT1,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 4,
@@ -281,6 +285,7 @@ static struct GfxDeviceInfo rklGt1fInfo = {
     .productFamily    = IGFX_ROCKETLAKE,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT0_5,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 4,
@@ -321,6 +326,7 @@ static struct GfxDeviceInfo adlsGt1Info = {
     .productFamily    = IGFX_ALDERLAKE_S,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT1,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 4,
@@ -342,6 +348,7 @@ static struct GfxDeviceInfo adlsGt1fInfo = {
     .productFamily    = IGFX_ALDERLAKE_S,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT0_5,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 4,
@@ -415,6 +422,7 @@ static struct GfxDeviceInfo adlpGt2Info = {
     .productFamily    = IGFX_ALDERLAKE_P,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT2,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 8,
@@ -436,56 +444,47 @@ static bool adlpGt2Device46A0 = DeviceInfoFactory<GfxDeviceInfo>::
 static bool adlpGt2Device46A1 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46A1, &adlpGt2Info);
 
-static bool adlpGt2Device46A2 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46A2, &adlpGt2Info);
-
 static bool adlpGt2Device46A3 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46A3, &adlpGt2Info);
-    
+
 static bool adlpGt2Device46A6 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46A6, &adlpGt2Info);
-    
-static bool adlpGt2Device46A8 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46A8, &adlpGt2Info);
-    
-static bool adlpGt2Device4628 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x4628, &adlpGt2Info);
-    
-    
+
+static bool adlpGt2Device4626 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x4626, &adlpGt2Info);
+
 static bool adlpGt2Device46B0 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46B0, &adlpGt2Info);
 
 static bool adlpGt2Device46B1 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46B1, &adlpGt2Info);
 
-static bool adlpGt2Device46B2 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46B2, &adlpGt2Info);
-
 static bool adlpGt2Device46B3 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x46B3, &adlpGt2Info);
-    
 
-static bool adlpGt2Device46C0 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46C0, &adlpGt2Info);
+static bool adlpGt2Device46A8 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x46A8, &adlpGt2Info);
 
-static bool adlpGt2Device46C1 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46C1, &adlpGt2Info);
+static bool adlpGt2Device4628 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x4628, &adlpGt2Info);
 
-static bool adlpGt2Device46C2 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46C2, &adlpGt2Info);
+static bool rplpGt2DeviceA7A0 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA7A0, &adlpGt2Info);
 
-static bool adlpGt2Device46C3 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46C3, &adlpGt2Info);
-    
-static bool adlpGt2Device46AA = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x46AA, &adlpGt2Info);
-    
-static bool adlpGt2Device462A = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x462A, &adlpGt2Info);
+static bool rplpGt2DeviceA720 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA720, &adlpGt2Info);
 
-static bool adlpGt2Device4626 = DeviceInfoFactory<GfxDeviceInfo>::
-    RegisterDevice(0x4626, &adlpGt2Info);
+static bool rplpGt2DeviceA7A8 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA7A8, &adlpGt2Info);
 
+static bool rplpGt2DeviceA7A1 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA7A1, &adlpGt2Info);
+
+static bool rplpGt2DeviceA721 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA721, &adlpGt2Info);
+
+static bool rplpGt2DeviceA7A9 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0xA7A9, &adlpGt2Info);
 #endif
 
 #ifdef IGFX_GEN12_ADLN_SUPPORTED
@@ -494,6 +493,7 @@ static struct GfxDeviceInfo adlnGt1Info = {
     .productFamily    = IGFX_ALDERLAKE_N,
     .displayFamily    = IGFX_GEN12_CORE,
     .renderFamily     = IGFX_GEN12_CORE,
+    .mediaFamily      = IGFX_UNKNOWN_CORE,
     .eGTType          = GTTYPE_GT1,
     .L3CacheSizeInKb  = 0,
     .L3BankCount      = 8,
