@@ -27,6 +27,7 @@
 #include "mos_solo_generic.h"
 #include "media_user_settings_mgr_g12_plus.h"
 #include "mhw_mi_itf.h"
+#include "mhw_vdbox_g12_X.h"
 
 namespace encode
 {
@@ -354,6 +355,9 @@ namespace encode
         CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnResourceWait(m_osInterface, &syncParams));
         m_osInterface->pfnSetResourceSyncTag(m_osInterface, &syncParams);
 
+        // Set flag to boost GPU frequency for low latency in remote gaming scenario
+        cmdBuffer.Attributes.bFrequencyBoost = (m_av1SeqParams->ScenarioInfo == ESCENARIO_REMOTEGAMING);
+
         ENCODE_CHK_STATUS_RETURN(RegisterPostCdef());
         ENCODE_CHK_STATUS_RETURN(PatchPictureLevelCommands(packetPhase, cmdBuffer));
 
@@ -683,7 +687,7 @@ namespace encode
         ENCODE_FUNC_CALL();
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-        CODECHAL_HW_FUNCTION_ENTER;
+        CODEC_HW_FUNCTION_ENTER;
 
         ENCODE_CHK_NULL_RETURN(statusReport);
         ENCODE_CHK_NULL_RETURN(m_hwInterface);
@@ -1152,6 +1156,31 @@ namespace encode
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS Av1VdencPktXe_M_Base::CalculateAvpCommandsSize()
+    {
+        uint32_t avpPictureStatesSize    = 0;
+        uint32_t avpPicturePatchListSize = 0;
+        uint32_t avpTileStatesSize       = 0;
+        uint32_t avpTilePatchListSize    = 0;
+
+        // Picture Level Commands
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(CalculateAvpPictureStateCommandSize(&avpPictureStatesSize, &avpPicturePatchListSize));
+
+        m_pictureStatesSize += avpPictureStatesSize;
+        m_picturePatchListSize += avpPicturePatchListSize;
+
+        // Tile Level Commands
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_hwInterface->GetAvpPrimitiveCommandSize(
+            CODECHAL_ENCODE_MODE_AV1,
+            &avpTileStatesSize,
+            &avpTilePatchListSize));
+
+        m_tileStatesSize += avpTileStatesSize;
+        m_tilePatchListSize += avpTilePatchListSize;
+
+        return MOS_STATUS_SUCCESS;
+    }
+
 #if USE_CODECHAL_DEBUG_TOOL
     MOS_STATUS Av1VdencPktXe_M_Base::DumpStatistics()
     {
