@@ -31,6 +31,7 @@
 #include "decode_basic_feature.h"
 #include "codec_def_decode_av1.h"
 #include "codechal_hw_g12_X.h"
+#include "decode_av1_basic_feature_g12.h"
 
 namespace decode
 {
@@ -345,9 +346,9 @@ public:
         CodechalHwInterface               *hwInterface);
 
 protected:
-    DecodeAllocator *   m_allocator    = nullptr;
-    Av1BasicFeature *   m_basicFeature = nullptr;
-    bool                m_resourceAllocated = false;
+    DecodeAllocator *    m_allocator         = nullptr;
+    Av1BasicFeatureG12 * m_basicFeature      = nullptr;
+    bool                 m_resourceAllocated = false;
 
     // Surfaces arrayfor GetRandomValues
     BufferArray *                     m_coordinatesRandomValuesSurfaceArray   = nullptr;                      //!< Random values for coordinates, 1D buffer, size = RoundUp(ImageWidth / 64) * RoundUp(ImageHeight / 64) * sizeof(int)
@@ -367,6 +368,7 @@ protected:
     BufferArray *                     m_yGammaLUTSurfaceArray                 = nullptr;                      //!< Input Y Gamma LUT surface, size = 256 * sizeof(short), 1D buffer
     BufferArray *                     m_uGammaLUTSurfaceArray                 = nullptr;                      //!< Input U Gamma LUT surface, size = 256 * sizeof(short), 1D buffer
     BufferArray *                     m_vGammaLUTSurfaceArray                 = nullptr;                      //!< Input V Gamma LUT surface, size = 256 * sizeof(short), 1D buffer
+MEDIA_CLASS_DEFINE_END(Av1DecodeFilmGrainG12)
 };
 
 }  // namespace decode
