@@ -1021,6 +1021,11 @@ namespace decode{
     {
         DECODE_FUNC_CALL();
 
+#ifdef _MMC_SUPPORTED
+        //Record each reference surface mmc state
+        uint8_t skipMask = 0;
+#endif
+
         if (m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != keyFrame && m_av1PicParams->m_picInfoFlags.m_fields.m_frameType != intraOnlyFrame)
         {
                 Av1SurfaceId surfaceId[av1TotalRefsPerFrame] = {
@@ -1062,8 +1067,24 @@ namespace decode{
             #ifdef _MMC_SUPPORTED
                 DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcState(refSurfaceParams[i].psSurface, &refSurfaceParams[i].mmcState));
                 DECODE_CHK_STATUS(m_mmcState->GetSurfaceMmcFormat(refSurfaceParams[i].psSurface, &refSurfaceParams[i].dwCompressionFormat));
+                if (refSurfaceParams[i].mmcState == MOS_MEMCOMP_DISABLED)
+                {
+                    skipMask |= (1 << i);
+                }
             #endif
             }
+            DECODE_NORMALMESSAGE("AV1 MMC skip masK is %d\n", skipMask);
+
+#ifdef _MMC_SUPPORTED
+            for (auto i = 0; i < av1TotalRefsPerFrame; i++)
+            {
+                // Set each refSurfaceParams mmcState as MOS_MEMCOMP_MC to satisfy MmcEnable in AddAvpSurfaceCmd
+                // Compression type/enable should be the same for all reference surface state
+                // The actual refSurfac mmcstate is recorded by skipMask
+                refSurfaceParams[i].mmcState    = MOS_MEMCOMP_MC;
+                refSurfaceParams[i].mmcSkipMask = skipMask;
+            }
+#endif
         }
 
         return MOS_STATUS_SUCCESS;
@@ -1263,7 +1284,7 @@ namespace decode{
 #endif
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-        if (MOS_GetTraceEventKeyword() & EVENT_DECODE_REFYUV_KEYWORD)
+        if (MOS_TraceKeyEnabled(TR_KEY_DECODE_REFYUV))
         {
             TraceDataDumpReferences(pipeBufAddrParams);
         }
@@ -1665,16 +1686,21 @@ namespace decode{
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
     MOS_STATUS Av1DecodePicPkt_G12_Base::TraceDataDumpInternalBuffers(MhwVdboxAvpPipeBufAddrParams &pipeBufAddrParams)
     {        
-        if (MOS_GetTraceEventKeyword() & EVENT_DECODE_INTERNAL_KEYWORD)
+        if (MOS_TraceKeyEnabled(TR_KEY_DECODE_INTERNAL))
         {
             if (m_av1BasicFeature->m_tileCoding.m_curTile == 0)
             {
-                m_osInterface->pfnDumpTraceGpuData(
-                    m_osInterface,
+                ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.m_cdfTableInitializationBuffer);
+                auto             pData = (uint8_t *)resLock.LockResourceForRead();
+                DECODE_CHK_NULL(pData);
+
+                MOS_TraceDataDump(
                     "Decode_Av1CdfTableInitBuffer",
                     0,
-                    pipeBufAddrParams.m_cdfTableInitializationBuffer,
+                    pData,
                     m_av1BasicFeature->m_cdfMaxNumBytes);
+
+                m_allocator->UnLock(pipeBufAddrParams.m_cdfTableInitializationBuffer);
             }
 
             if (m_av1BasicFeature->m_tileCoding.m_curTile == 0)
@@ -1682,12 +1708,17 @@ namespace decode{
                 if (pipeBufAddrParams.m_segmentIdReadBuffer != nullptr &&
                     !m_allocator->ResourceIsNull(pipeBufAddrParams.m_segmentIdReadBuffer))
                 {
-                    m_osInterface->pfnDumpTraceGpuData(
-                        m_osInterface,
+                    ResourceAutoLock resLock(m_allocator, pipeBufAddrParams.m_segmentIdReadBuffer);
+                    auto             pData = (uint8_t *)resLock.LockResourceForRead();
+                    DECODE_CHK_NULL(pData);
+                    
+                    MOS_TraceDataDump(
                         "Decode_Av1SegmentIdReadBuffer",
                         0,
-                        pipeBufAddrParams.m_segmentIdReadBuffer,
+                        pData,
                         m_widthInSb * m_heightInSb * CODECHAL_CACHELINE_SIZE);
+
+                    m_allocator->UnLock(pipeBufAddrParams.m_segmentIdReadBuffer);
                 }
             }
         }
@@ -1775,12 +1806,15 @@ namespace decode{
 
                         ResourceAutoLock resLock(m_allocator, &m_tempRefSurf->OsResource);
                         auto             pData = (uint8_t *)resLock.LockResourceForRead();
+                        DECODE_CHK_NULL(pData);
 
                         MOS_TraceDataDump(
                             "Decode_AV1RefSurf",
                             n,
                             pData,
                             (uint32_t)m_tempRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+                        
+                        m_allocator->UnLock(&m_tempRefSurf->OsResource);
                     }
                 }
             }
