@@ -163,8 +163,8 @@ MOS_STATUS SwFilterCsc::Configure(VP_PIPELINE_PARAMS &params, bool isInputSurf,
     m_Params.formatOutput           = surfOutput->Format;
     m_Params.input.chromaSiting     = surfInput->ChromaSiting;
     m_Params.output.chromaSiting    = surfOutput->ChromaSiting;
-    // Will be assigned duringPolicySfcAlphaHandler::UpdateFeaturePipe.
-    m_Params.pAlphaParams           = nullptr;
+    // Alpha should be handled in input pipe to avoid alpha data lost from image.
+    m_Params.pAlphaParams           = params.pCompAlpha;
 
     return MOS_STATUS_SUCCESS;
 }
@@ -362,8 +362,8 @@ MOS_STATUS SwFilterScaling::Configure(VP_PIPELINE_PARAMS &params, bool isInputSu
     m_Params.csc.colorSpaceOutput   = surfOutput->ColorSpace;
     // Will be assigned during PolicySfcColorFillHandler::UpdateFeaturePipe.
     m_Params.pColorFillParams       = nullptr;
-    // Will be assigned during PolicySfcAlphaHandler::UpdateFeaturePipe.
-    m_Params.pCompAlpha             = nullptr;
+    // Alpha should be handled in input pipe to avoid alpha data lost from image.
+    m_Params.pCompAlpha             = params.pCompAlpha;
 
     if (surfInput->Rotation == VPHAL_ROTATION_IDENTITY ||
         surfInput->Rotation == VPHAL_ROTATION_180 ||
@@ -389,10 +389,27 @@ MOS_STATUS SwFilterScaling::Configure(VP_PIPELINE_PARAMS &params, bool isInputSu
         RECT_ROTATE(m_Params.output.rcMaxSrc, surfOutput->rcMaxSrc);
     }
 
-    m_Params.interlacedScalingType  = surfInput->InterlacedScalingType;
+    m_Params.bTargetRectangle = !((surfOutput->rcSrc.left == 0) && (surfOutput->rcSrc.top == 0) && (surfOutput->rcSrc.bottom == surfOutput->dwHeight) && (surfOutput->rcSrc.right == surfOutput->dwWidth));
+    VP_PUBLIC_NORMALMESSAGE("Target Rectangle is enabled: %d", m_Params.bTargetRectangle);
+
+    if (surfInput->bInterlacedScaling)
+    {
+        m_Params.interlacedScalingType = ISCALING_INTERLEAVED_TO_INTERLEAVED;
+    }
+    else if (surfInput->bFieldWeaving)
+    {
+        m_Params.interlacedScalingType = ISCALING_FIELD_TO_INTERLEAVED;
+    }
+    else
+    {
+        m_Params.interlacedScalingType = surfInput->InterlacedScalingType;
+    }
+
     m_Params.input.sampleType       = surfInput->SampleType;
     m_Params.output.sampleType      = surfOutput->SampleType;
 
+    VP_PUBLIC_NORMALMESSAGE("interlacedScalingType %d", m_Params.interlacedScalingType);
+
     // For field-to-interleaved scaling, the height of rcSrcInput is input field height,
     // the height of rcDstInput is output frame height, for scaling ratio calculation, the
     // bottom of rcDstInput need to divide 2.
@@ -409,6 +426,11 @@ MOS_STATUS SwFilterScaling::Configure(VP_PIPELINE_PARAMS &params, bool isInputSu
         m_Params.output.dwHeight *= 2;
     }
 
+    VP_PUBLIC_NORMALMESSAGE("Configure scaling parameters by VP_PIPELINE_PARAMS: intput %d x %d, output %d x %d, (%d, %d, %d, %d) -> (%d, %d, %d, %d)",
+        m_Params.input.dwWidth, m_Params.input.dwHeight, m_Params.output.dwWidth, m_Params.output.dwHeight,
+        m_Params.input.rcSrc.left, m_Params.input.rcSrc.top, m_Params.input.rcSrc.right, m_Params.input.rcSrc.bottom,
+        m_Params.input.rcDst.left, m_Params.input.rcDst.top, m_Params.input.rcDst.right, m_Params.input.rcDst.bottom);
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -457,6 +479,59 @@ MOS_STATUS SwFilterScaling::Configure(VEBOX_SFC_PARAMS &params)
         RECT_ROTATE(m_Params.output.rcMaxSrc, recOutput);
     }
 
+    VP_PUBLIC_NORMALMESSAGE("Configure scaling parameters by VEBOX_SFC_PARAMS: intput %d x %d, output %d x %d, (%d, %d, %d, %d) -> (%d, %d, %d, %d)",
+        m_Params.input.dwWidth, m_Params.input.dwHeight, m_Params.output.dwWidth, m_Params.output.dwHeight,
+        m_Params.input.rcSrc.left, m_Params.input.rcSrc.top, m_Params.input.rcSrc.right, m_Params.input.rcSrc.bottom,
+        m_Params.input.rcDst.left, m_Params.input.rcDst.top, m_Params.input.rcDst.right, m_Params.input.rcDst.bottom);
+
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS SwFilterScaling::Configure(PVP_SURFACE surfInput, PVP_SURFACE surfOutput, VP_EXECUTE_CAPS caps)
+{
+    VP_FUNC_CALL();
+
+    VP_PUBLIC_CHK_NULL_RETURN(surfInput);
+    VP_PUBLIC_CHK_NULL_RETURN(surfInput->osSurface);
+    VP_PUBLIC_CHK_NULL_RETURN(surfOutput);
+    VP_PUBLIC_CHK_NULL_RETURN(surfOutput->osSurface);
+
+    m_Params.type                       = FeatureTypeScaling;
+    m_Params.formatInput                = surfInput->osSurface->Format;
+    m_Params.formatOutput               = surfOutput->osSurface->Format;
+
+    m_Params.input.dwWidth              = surfInput->osSurface->dwWidth;
+    m_Params.input.dwHeight             = surfInput->osSurface->dwHeight;
+    m_Params.input.rcSrc                = surfInput->rcSrc;
+    m_Params.input.rcDst                = surfInput->rcDst;
+    m_Params.input.rcMaxSrc             = surfInput->rcMaxSrc;
+    m_Params.input.sampleType           = surfInput->SampleType;
+
+    m_Params.rotation.rotationNeeded    = false;
+    m_Params.output.dwWidth             = surfOutput->osSurface->dwWidth;
+    m_Params.output.dwHeight            = surfOutput->osSurface->dwHeight;
+    m_Params.output.rcSrc               = surfOutput->rcSrc;
+    m_Params.output.rcDst               = surfOutput->rcDst;
+    m_Params.output.rcMaxSrc            = surfOutput->rcMaxSrc;
+    m_Params.output.sampleType          = surfOutput->SampleType;
+
+    m_Params.isPrimary                  = SURF_IN_PRIMARY == surfInput->SurfType;
+    m_Params.scalingMode                = VPHAL_SCALING_NEAREST;
+    m_Params.scalingPreference          = VPHAL_SCALING_PREFER_SFC;
+
+    m_Params.interlacedScalingType      = ISCALING_NONE;
+    m_Params.pColorFillParams           = nullptr;
+    m_Params.pCompAlpha                 = nullptr;
+    m_Params.bDirectionalScalar         = false;
+
+    m_Params.csc.colorSpaceOutput       = surfOutput->ColorSpace;
+    m_Params.rotation.rotationNeeded    = false;
+
+    VP_PUBLIC_NORMALMESSAGE("Configure scaling parameters by Surfaces: intput %d x %d, output %d x %d, (%d, %d, %d, %d) -> (%d, %d, %d, %d)",
+        m_Params.input.dwWidth, m_Params.input.dwHeight, m_Params.output.dwWidth, m_Params.output.dwHeight,
+        m_Params.input.rcSrc.left, m_Params.input.rcSrc.top, m_Params.input.rcSrc.right, m_Params.input.rcSrc.bottom,
+        m_Params.input.rcDst.left, m_Params.input.rcDst.top, m_Params.input.rcDst.right, m_Params.input.rcDst.bottom);
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -569,6 +644,11 @@ MOS_STATUS SwFilterScaling::Update(VP_SURFACE *inputSurf, VP_SURFACE *outputSurf
     // update source sample type for field to interleaved mode.
     m_Params.input.sampleType       = inputSurf->SampleType;
 
+    VP_PUBLIC_NORMALMESSAGE("Update scaling parameters: intput %d x %d, output %d x %d, (%d, %d, %d, %d) -> (%d, %d, %d, %d)",
+        m_Params.input.dwWidth, m_Params.input.dwHeight, m_Params.output.dwWidth, m_Params.output.dwHeight,
+        m_Params.input.rcSrc.left, m_Params.input.rcSrc.top, m_Params.input.rcSrc.right, m_Params.input.rcSrc.bottom,
+        m_Params.input.rcDst.left, m_Params.input.rcDst.top, m_Params.input.rcDst.right, m_Params.input.rcDst.bottom);
+
     return MOS_STATUS_SUCCESS;
 }
 /****************************************************************************************************/
@@ -703,6 +783,21 @@ MOS_STATUS SwFilterDenoise::Configure(VP_PIPELINE_PARAMS& params, bool isInputSu
     m_Params.denoiseParams.bEnableChroma =
         m_Params.denoiseParams.bEnableChroma && m_Params.denoiseParams.bEnableLuma;
 
+    GMM_RESOURCE_INFO* pSrcGmmResInfo    = surfInput->OsResource.pGmmResInfo;
+    GMM_RESOURCE_INFO* pTargetGmmResInfo = params.pTarget[0]->OsResource.pGmmResInfo;
+    VP_PUBLIC_CHK_NULL_RETURN(pSrcGmmResInfo);
+    VP_PUBLIC_CHK_NULL_RETURN(pTargetGmmResInfo);
+
+    bool inputProtected = pSrcGmmResInfo->GetSetCpSurfTag(0, 0);
+    bool outputProtected = pTargetGmmResInfo->GetSetCpSurfTag(0, 0);
+
+    if (inputProtected || outputProtected ||
+       (m_vpInterface.GetHwInterface()->m_osInterface->osCpInterface &&
+        m_vpInterface.GetHwInterface()->m_osInterface->osCpInterface->IsHMEnabled()))
+    {
+        m_Params.secureDnNeeded = true;
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1422,6 +1517,15 @@ MOS_STATUS SwFilterColorFill::Configure(VP_PIPELINE_PARAMS& params, bool isInput
     m_Params.formatOutput   = surfOutput->Format;
     m_Params.colorFillParams = params.pColorFillParams;
 
+    if (m_Params.colorFillParams)
+    {
+        VP_PUBLIC_NORMALMESSAGE("Color 0x%x, CSpace %d", m_Params.colorFillParams->Color, m_Params.colorFillParams->CSpace);
+    }
+    else
+    {
+        VP_PUBLIC_NORMALMESSAGE("nullptr == m_Params.colorFillParams");
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1461,8 +1565,14 @@ MOS_STATUS vp::SwFilterColorFill::Update(VP_SURFACE* inputSurf, VP_SURFACE* outp
 {
     VP_FUNC_CALL();
 
-    VP_PUBLIC_CHK_NULL_RETURN(inputSurf);
-    VP_PUBLIC_CHK_NULL_RETURN(inputSurf->osSurface);
+    if (nullptr == inputSurf)
+    {
+        VP_PUBLIC_NORMALMESSAGE("ColorFill does not have input surface!");
+    }
+    else
+    {
+        VP_PUBLIC_CHK_NULL_RETURN(inputSurf->osSurface);
+    }
     VP_PUBLIC_CHK_NULL_RETURN(outputSurf);
     VP_PUBLIC_CHK_NULL_RETURN(outputSurf->osSurface);
     m_Params.formatInput = outputSurf->osSurface->Format;
@@ -1505,6 +1615,9 @@ VP_EngineEntry SwFilterColorFill::GetCombinedFilterEngineCaps(SwFilterSubPipe *i
             engineCaps.VeboxNeeded = 0;
             engineCaps.SfcNeeded = 0;
             engineCaps.bypassIfVeboxSfcInUse = 1;
+            VP_PUBLIC_NORMALMESSAGE("engineCaps updated. value 0x%x (bEnabled %d, VeboxNeeded %d, SfcNeeded %d, RenderNeeded %d, fcSupported %d, isolated %d)",
+                engineCaps.value, engineCaps.bEnabled, engineCaps.VeboxNeeded, engineCaps.SfcNeeded,
+                engineCaps.RenderNeeded, engineCaps.fcSupported, engineCaps.isolated);
         }
 
         return engineCaps;
@@ -1550,6 +1663,15 @@ MOS_STATUS SwFilterAlpha::Configure(VP_PIPELINE_PARAMS& params, bool isInputSurf
     m_Params.compAlpha      = params.pCompAlpha;
     m_Params.calculatingAlpha = params.bCalculatingAlpha;
 
+    if (m_Params.compAlpha)
+    {
+        VP_PUBLIC_NORMALMESSAGE("AlphaMode %d, fAlpha %f", m_Params.compAlpha->AlphaMode, m_Params.compAlpha->fAlpha);
+    }
+    else
+    {
+        VP_PUBLIC_NORMALMESSAGE("nullptr == m_Params.compAlpha");
+    }
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -1589,8 +1711,14 @@ MOS_STATUS vp::SwFilterAlpha::Update(VP_SURFACE* inputSurf, VP_SURFACE* outputSu
 {
     VP_FUNC_CALL();
 
-    VP_PUBLIC_CHK_NULL_RETURN(inputSurf);
-    VP_PUBLIC_CHK_NULL_RETURN(inputSurf->osSurface);
+    if (nullptr == inputSurf)
+    {
+        VP_PUBLIC_NORMALMESSAGE("Alpha does not have input surface!");
+    }
+    else
+    {
+        VP_PUBLIC_CHK_NULL_RETURN(inputSurf->osSurface);
+    }
     VP_PUBLIC_CHK_NULL_RETURN(outputSurf);
     VP_PUBLIC_CHK_NULL_RETURN(outputSurf->osSurface);
     m_Params.formatInput = outputSurf->osSurface->Format;
