@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -326,7 +326,7 @@ class VpRenderKernelObj
 {
 public:
     VpRenderKernelObj(PVP_MHWINTERFACE hwInterface, PVpAllocator allocator);
-    VpRenderKernelObj(PVP_MHWINTERFACE hwInterface, VpKernelID kernelID, uint32_t kernelIndex);
+    VpRenderKernelObj(PVP_MHWINTERFACE hwInterface, VpKernelID kernelID, uint32_t kernelIndex, std::string kernelName = "", PVpAllocator allocator = nullptr);
     virtual ~VpRenderKernelObj();
 
     // For Adv kernel
@@ -334,7 +334,12 @@ public:
     // GetCurbeState should be called after UpdateCurbeBindingIndex for all processed surfaces being called
     virtual MOS_STATUS Init(VpRenderKernel& kernel);
 
-    virtual MOS_STATUS GetCurbeState(void*& curbe, uint32_t& curbeLength) = 0;
+    MOS_STATUS GetCurbeState(void *&curbe, uint32_t &curbeLength, uint32_t &curbeLengthAligned, RENDERHAL_KERNEL_PARAM kernelParam, uint32_t dwBlockAlign)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(GetCurbeState(curbe, curbeLength));
+        VP_PUBLIC_CHK_STATUS_RETURN(GetAlignedLength(curbeLength, curbeLengthAligned, kernelParam, dwBlockAlign));
+        return MOS_STATUS_SUCCESS;
+    }
 
     virtual uint32_t GetInlineDataSize() = 0;
 
@@ -360,7 +365,15 @@ public:
     virtual MOS_STATUS SetKernelConfigs(
         KERNEL_PARAMS& kernelParams,
         VP_SURFACE_GROUP& surfaces,
-        KERNEL_SAMPLER_STATE_GROUP& samplerStateGroup);
+        KERNEL_SAMPLER_STATE_GROUP& samplerStateGroup,
+        KERNEL_CONFIGS& kernelConfigs,
+        VP_PACKET_SHARED_CONTEXT* sharedContext);
+
+    virtual MOS_STATUS GetScoreboardParams(PMHW_VFE_SCOREBOARD &scoreboardParams)
+    {
+        scoreboardParams = nullptr;
+        return MOS_STATUS_SUCCESS;
+    }
 
     virtual void DumpSurfaces()
     {
@@ -481,7 +494,7 @@ protected:
 
     virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE& threadSpace, bool bSyncFlag);
 
-    virtual MOS_STATUS SetKernelArgs(KERNEL_ARGS& kernelArgs);
+    virtual MOS_STATUS SetKernelArgs(KERNEL_ARGS &kernelArgs, VP_PACKET_SHARED_CONTEXT *sharedContext);
 
     virtual MOS_STATUS SetupSurfaceState() = 0;
 
@@ -493,6 +506,15 @@ protected:
         VP_RENDER_CHK_STATUS_RETURN(SetupSurfaceState());
         return MOS_STATUS_SUCCESS;
     }
+
+    virtual MOS_STATUS GetCurbeState(void *&curbe, uint32_t &curbeLength) = 0;
+
+    virtual MOS_STATUS GetAlignedLength(uint32_t &curbeLength, uint32_t &curbeLengthAligned, RENDERHAL_KERNEL_PARAM kernelParam, uint32_t dwBlockAlign)
+    {
+        curbeLengthAligned = MOS_ALIGN_CEIL(curbeLength, dwBlockAlign);
+        return MOS_STATUS_SUCCESS;
+    }
+
 protected:
 
     VP_SURFACE_GROUP                                        *m_surfaceGroup = nullptr;  // input surface process surface groups
@@ -500,6 +522,7 @@ protected:
     KERNEL_SURFACE_CONFIG                                   m_surfaceState;             // surfaces processed pool where the surface state will generated here, if KERNEL_SURFACE_STATE_PARAM 
     KERNEL_SURFACE_BINDING_INDEX                            m_surfaceBindingIndex;      // store the binding index for processed surface
     PVpAllocator                                            m_allocator = nullptr;
+    MediaUserSettingSharedPtr                               m_userSettingPtr = nullptr;  // usersettingInstance
 
     // kernel attribute 
     std::string                                             m_kernelName = "";
@@ -510,6 +533,10 @@ protected:
     KernelIndex                                             m_kernelIndex = 0;          // index of current kernel in KERNEL_PARAMS_LIST
 
     bool                                                    m_isAdvKernel = false;      // true mean multi kernel can be submitted in one workload.
+
+    std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
+
+MEDIA_CLASS_DEFINE_END(VpRenderKernelObj)
 };
 }
 #endif // __VP_RENDER_KERNEL_OBJ_H__
